diff --git a/7DaysToDie/sdtdserver b/7DaysToDie/sdtdserver
index 116eb9ce6..82b8d91b4 100644
--- a/7DaysToDie/sdtdserver
+++ b/7DaysToDie/sdtdserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="username"
steampass="password"
diff --git a/ARKSurvivalEvolved/arkserver b/ARKSurvivalEvolved/arkserver
index 90d262694..17e3e5d78 100644
--- a/ARKSurvivalEvolved/arkserver
+++ b/ARKSurvivalEvolved/arkserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/Arma3/arma3server b/Arma3/arma3server
index 7215de44d..a13da2112 100644
--- a/Arma3/arma3server
+++ b/Arma3/arma3server
@@ -14,11 +14,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="username"
steampass="password"
diff --git a/BlackMesa/bmdmserver b/BlackMesa/bmdmserver
index 6d8ffbc2e..1a2041f85 100644
--- a/BlackMesa/bmdmserver
+++ b/BlackMesa/bmdmserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/BladeSymphony/bsserver b/BladeSymphony/bsserver
index 87c48e89c..aecefd762 100644
--- a/BladeSymphony/bsserver
+++ b/BladeSymphony/bsserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="username"
steampass="password"
diff --git a/BrainBread2/bb2server b/BrainBread2/bb2server
index 2afc3fe32..ac24012fd 100644
--- a/BrainBread2/bb2server
+++ b/BrainBread2/bb2server
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="username"
steampass="password"
diff --git a/CodenameCURE/ccserver b/CodenameCURE/ccserver
index 7b4b0dde6..8fe4042fd 100644
--- a/CodenameCURE/ccserver
+++ b/CodenameCURE/ccserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/CounterStrike/csserver b/CounterStrike/csserver
index 55b9d4b35..84b161835 100644
--- a/CounterStrike/csserver
+++ b/CounterStrike/csserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/CounterStrikeConditionZero/csczserver b/CounterStrikeConditionZero/csczserver
index 9f0df0574..e2cfa1d5d 100644
--- a/CounterStrikeConditionZero/csczserver
+++ b/CounterStrikeConditionZero/csczserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/CounterStrikeGlobalOffensive/csgoserver b/CounterStrikeGlobalOffensive/csgoserver
index 3e1b51874..74755e92b 100755
--- a/CounterStrikeGlobalOffensive/csgoserver
+++ b/CounterStrikeGlobalOffensive/csgoserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/CounterStrikeSource/cssserver b/CounterStrikeSource/cssserver
index 7ab14251b..59f0bcc47 100644
--- a/CounterStrikeSource/cssserver
+++ b/CounterStrikeSource/cssserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/DayOfDefeat/dodserver b/DayOfDefeat/dodserver
index 20444a2de..1a4ad7f93 100644
--- a/DayOfDefeat/dodserver
+++ b/DayOfDefeat/dodserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/DayOfDefeatSource/dodsserver b/DayOfDefeatSource/dodsserver
index 8a13ced73..a169281d0 100644
--- a/DayOfDefeatSource/dodsserver
+++ b/DayOfDefeatSource/dodsserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/DeathmatchClassic/dmcserver b/DeathmatchClassic/dmcserver
index 49e204d51..c4555e9eb 100644
--- a/DeathmatchClassic/dmcserver
+++ b/DeathmatchClassic/dmcserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/DontStarveTogether/dstserver b/DontStarveTogether/dstserver
index 09f54a6de..c118ee466 100644
--- a/DontStarveTogether/dstserver
+++ b/DontStarveTogether/dstserver
@@ -13,11 +13,18 @@ version="130516"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/DoubleActionBoogaloo/dabserver b/DoubleActionBoogaloo/dabserver
index 24f2dafdc..1277563ed 100644
--- a/DoubleActionBoogaloo/dabserver
+++ b/DoubleActionBoogaloo/dabserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/FistfulOfFrags/fofserver b/FistfulOfFrags/fofserver
index ff1a02a24..259464c7a 100644
--- a/FistfulOfFrags/fofserver
+++ b/FistfulOfFrags/fofserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/GarrysMod/gmodserver b/GarrysMod/gmodserver
index 212072989..53d8b1628 100644
--- a/GarrysMod/gmodserver
+++ b/GarrysMod/gmodserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/GoldenEyeSource/gesserver b/GoldenEyeSource/gesserver
index cbc710bc7..90339be94 100644
--- a/GoldenEyeSource/gesserver
+++ b/GoldenEyeSource/gesserver
@@ -14,11 +14,18 @@ version="150316"
#### Variables ####
export MALLOC_CHECK_=0
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/HalfLife2Deathmatch/hl2dmserver b/HalfLife2Deathmatch/hl2dmserver
index b67986749..b7c08dd6a 100644
--- a/HalfLife2Deathmatch/hl2dmserver
+++ b/HalfLife2Deathmatch/hl2dmserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/HalfLifeDeathmatch/hldmserver b/HalfLifeDeathmatch/hldmserver
index 55f5fd749..d60aa3693 100644
--- a/HalfLifeDeathmatch/hldmserver
+++ b/HalfLifeDeathmatch/hldmserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/HalfLifeDeathmatchSource/hldmsserver b/HalfLifeDeathmatchSource/hldmsserver
index 9db71678c..864549967 100644
--- a/HalfLifeDeathmatchSource/hldmsserver
+++ b/HalfLifeDeathmatchSource/hldmsserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/Hurtworld/hwserver b/Hurtworld/hwserver
index 47be057d8..e46a9a94b 100644
--- a/Hurtworld/hwserver
+++ b/Hurtworld/hwserver
@@ -14,11 +14,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/Insurgency/insserver b/Insurgency/insserver
index 4803e65dd..5edc7c55e 100644
--- a/Insurgency/insserver
+++ b/Insurgency/insserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/JustCause2/jc2server b/JustCause2/jc2server
index 5cb7ca499..c0222fccf 100644
--- a/JustCause2/jc2server
+++ b/JustCause2/jc2server
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/KillingFloor/kfserver b/KillingFloor/kfserver
index 9ce398a66..9fbee8f44 100644
--- a/KillingFloor/kfserver
+++ b/KillingFloor/kfserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="username"
steampass="password"
diff --git a/Left4Dead/l4dserver b/Left4Dead/l4dserver
index a02794d06..67d4b1024 100644
--- a/Left4Dead/l4dserver
+++ b/Left4Dead/l4dserver
@@ -14,11 +14,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/Left4Dead2/l4d2server b/Left4Dead2/l4d2server
index 20add85dd..ef4710ab3 100644
--- a/Left4Dead2/l4d2server
+++ b/Left4Dead2/l4d2server
@@ -13,11 +13,21 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
+# Pushover
+#Push alot
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/Mumble/mumbleserver b/Mumble/mumbleserver
index e7302f9be..e64580c14 100644
--- a/Mumble/mumbleserver
+++ b/Mumble/mumbleserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Server Details
gamename="Mumble"
servicename="mumble-server"
diff --git a/NS2Combat/ns2cserver b/NS2Combat/ns2cserver
index f0f9df415..4b4628724 100644
--- a/NS2Combat/ns2cserver
+++ b/NS2Combat/ns2cserver
@@ -13,11 +13,18 @@ version="220416"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="username"
steampass="password"
diff --git a/NaturalSelection2/ns2server b/NaturalSelection2/ns2server
index 9c6906d6b..a89192c53 100644
--- a/NaturalSelection2/ns2server
+++ b/NaturalSelection2/ns2server
@@ -13,11 +13,18 @@ version="220416"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="username"
steampass="password"
diff --git a/NoMoreRoomInHell/nmrihserver b/NoMoreRoomInHell/nmrihserver
index c8de59f28..1f0a3ce7a 100644
--- a/NoMoreRoomInHell/nmrihserver
+++ b/NoMoreRoomInHell/nmrihserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/OpposingForce/opforserver b/OpposingForce/opforserver
index 5f00c4e1c..1da4dc2ce 100644
--- a/OpposingForce/opforserver
+++ b/OpposingForce/opforserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/PiratesVikingandKnightsII/pvkiiserver b/PiratesVikingandKnightsII/pvkiiserver
index 42ab9aac3..05956597e 100644
--- a/PiratesVikingandKnightsII/pvkiiserver
+++ b/PiratesVikingandKnightsII/pvkiiserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/ProjectZomboid/pzserver b/ProjectZomboid/pzserver
index 3d758dd82..c8c3ae07a 100644
--- a/ProjectZomboid/pzserver
+++ b/ProjectZomboid/pzserver
@@ -14,11 +14,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/QuakeLive/qlserver b/QuakeLive/qlserver
index c65da408a..f47aee840 100755
--- a/QuakeLive/qlserver
+++ b/QuakeLive/qlserver
@@ -13,11 +13,18 @@ version="060516"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/README.md b/README.md
index c4c61df3a..6d395dafb 100644
--- a/README.md
+++ b/README.md
@@ -4,7 +4,7 @@
[](https://travis-ci.org/dgibbs64/linuxgsm)
[](http://waffle.io/dgibbs64/linuxgsm)
-The Linux Game Server Managers are command line tools for quick, simple deployment and management of various dedicated game servers and voice comms servers.
+The Linux Game Server Managers are command line tools for quick, simple deployment and management of various dedicated game servers and voice alert servers.
Hassle-Free Dedicated Servers
Game servers traditionally are not easy to manage yourself. Admins often have to spend hours just messing around trying to get their server working. LGSM is designed to be a simple as possible allowing Admins to spend less time on management and more time on the fun stuff.
@@ -15,7 +15,8 @@ Game servers traditionally are not easy to manage yourself. Admins often have to
Console
Details
Installer (SteamCMD)
- Monitor (including email notification)
+ Monitor
+ Alerts (Email, Pushbullet)
Update (SteamCMD)
Start/Stop/Restart server
diff --git a/RedOrchestra/roserver b/RedOrchestra/roserver
index 84d00b6f8..a9e1f2afd 100644
--- a/RedOrchestra/roserver
+++ b/RedOrchestra/roserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="username"
steampass="password"
diff --git a/Ricochet/ricochetserver b/Ricochet/ricochetserver
index 067065811..b1173fd90 100644
--- a/Ricochet/ricochetserver
+++ b/Ricochet/ricochetserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/Rust/rustserver b/Rust/rustserver
index b3a972c1d..119fb9115 100644
--- a/Rust/rustserver
+++ b/Rust/rustserver
@@ -14,11 +14,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login (not required)
steamuser="anonymous"
steampass=""
diff --git a/SeriousSam3BFE/ss3sserver b/SeriousSam3BFE/ss3sserver
index 60bcc0230..8905df1b2 100644
--- a/SeriousSam3BFE/ss3sserver
+++ b/SeriousSam3BFE/ss3sserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/StarBound/sbserver b/StarBound/sbserver
index 881d6c5fc..9fa5e639a 100644
--- a/StarBound/sbserver
+++ b/StarBound/sbserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="username"
steampass="password"
diff --git a/SvenCoop/svencoopserver b/SvenCoop/svencoopserver
index 9d2ceb2f9..6daa9d75d 100644
--- a/SvenCoop/svencoopserver
+++ b/SvenCoop/svencoopserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/TeamFortress2/tf2server b/TeamFortress2/tf2server
index 671942f71..4f8d0d6df 100644
--- a/TeamFortress2/tf2server
+++ b/TeamFortress2/tf2server
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/TeamFortressClassic/tfcserver b/TeamFortressClassic/tfcserver
index fbcbe3227..0093b7721 100644
--- a/TeamFortressClassic/tfcserver
+++ b/TeamFortressClassic/tfcserver
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="anonymous"
steampass=""
diff --git a/TeamSpeak3/ts3server b/TeamSpeak3/ts3server
index 835113f78..b60066782 100644
--- a/TeamSpeak3/ts3server
+++ b/TeamSpeak3/ts3server
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Start Variables
updateonstart="off"
diff --git a/Teeworlds/twserver b/Teeworlds/twserver
index 19a766260..aa45d1376 100644
--- a/Teeworlds/twserver
+++ b/Teeworlds/twserver
@@ -14,11 +14,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="username"
steampass="password"
diff --git a/Terraria/terrariaserver b/Terraria/terrariaserver
index 7e1b35db2..32151b0ab 100644
--- a/Terraria/terrariaserver
+++ b/Terraria/terrariaserver
@@ -14,11 +14,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Steam login
steamuser="username"
steampass="password"
diff --git a/UnrealTournament2004/ut2k4server b/UnrealTournament2004/ut2k4server
index f0d1efc29..9a3362bf7 100644
--- a/UnrealTournament2004/ut2k4server
+++ b/UnrealTournament2004/ut2k4server
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Start Variables
defaultmap="DM-Rankin"
ip="0.0.0.0"
diff --git a/UnrealTournament99/ut99server b/UnrealTournament99/ut99server
index 890f028c6..4c8e50635 100644
--- a/UnrealTournament99/ut99server
+++ b/UnrealTournament99/ut99server
@@ -13,11 +13,18 @@ version="150316"
#### Variables ####
-# Notification Email
+# Notification Alerts
# (on|off)
-emailnotification="off"
+
+# Email
+emailalert="off"
email="email@example.com"
+# Pushbullet
+# https://www.pushbullet.com/#settings
+pushbulletalert"off"
+pushbullettoken="accesstoken"
+
# Start Variables
defaultmap="DM-Deck16]["
ip="0.0.0.0"
diff --git a/lgsm/functions/alert.sh b/lgsm/functions/alert.sh
new file mode 100644
index 000000000..e904933c8
--- /dev/null
+++ b/lgsm/functions/alert.sh
@@ -0,0 +1,15 @@
+#!/bin/bash
+# LGSM alert.sh function
+# Author: Daniel Gibbs
+# Website: https://gameservermanagers.com
+lgsm_version="140516"
+
+# Description: Overall function for managing alerts.
+
+if [ "${emailalert}" == "on" ]||[ -n "${email}" ]; then
+ alert_email.sh
+fi
+
+if [ "${pushbulletalert}" == "on" ]||[ -n "${pushbullettoken}" ]; then
+ alert_pushbullet.sh
+fi
\ No newline at end of file
diff --git a/lgsm/functions/alert_pushbullet.sh b/lgsm/functions/alert_pushbullet.sh
new file mode 100644
index 000000000..f47ad7e30
--- /dev/null
+++ b/lgsm/functions/alert_pushbullet.sh
@@ -0,0 +1,14 @@
+#!/bin/bash
+# LGSM alert_pushbullet.sh function
+# Author: Daniel Gibbs
+# Website: https://gameservermanagers.com
+lgsm_version="140516"
+
+# Description: alerts using pushbullet.
+
+local modulename="Alert"
+function_selfname="$(basename $(readlink -f "${BASH_SOURCE[0]}"))"
+
+curl -u """${pushbullettoken}"":" -d type="note" -d body="${alertbody}" -d title="${alertsubject}" 'https://api.pushbullet.com/v2/pushes' >/dev/null 2>&1
+fn_print_ok_nl "Sent Pushbullet alert"
+fn_scriptlog "Sent Pushbullet alert"
diff --git a/lgsm/functions/check_deps.sh b/lgsm/functions/check_deps.sh
index 8f9de49f8..49498d2ff 100644
--- a/lgsm/functions/check_deps.sh
+++ b/lgsm/functions/check_deps.sh
@@ -38,8 +38,8 @@ fn_deps_detector(){
}
fn_deps_email(){
- # Adds postfix to required dependencies if email notification is enabled
- if [ "${emailnotification}" == "on" ]; then
+ # Adds postfix to required dependencies if email alert is enabled
+ if [ "${emailalert}" == "on" ]; then
if [ -f /usr/bin/mailx ]; then
if [ -d /etc/exim4 ]; then
array_deps_required+=( exim4 )
diff --git a/lgsm/functions/command_comms_check.sh b/lgsm/functions/command_comms_check.sh
deleted file mode 100644
index 1d401d948..000000000
--- a/lgsm/functions/command_comms_check.sh
+++ /dev/null
@@ -1,22 +0,0 @@
-#!/bin/bash
-# LGSM command_email_test.sh function
-# Author: Daniel Gibbs
-# Website: https://gameservermanagers.com
-lgsm_version="140516"
-
-# Description: Sends a test email notification.
-
-local modulename="Comms"
-function_selfname="$(basename $(readlink -f "${BASH_SOURCE[0]}"))"
-
-check.sh
-info_config.sh
-if [ "${emailnotification}" = "on" ]||[ "${pushbulletnotification}" = "on" ]; then
- fn_scriptlog "Sending Comms Check"
- commssubject="LGSM - Comms Check - ${servername}"
- commsbody="LGSM testing comms, how you read?"
- comms.sh
-else
- fn_print_fail_nl "Notifications not enabled"
- fn_scriptlog "Notifications not enabled"
-fi
\ No newline at end of file
diff --git a/lgsm/functions/command_monitor.sh b/lgsm/functions/command_monitor.sh
index cb7c51d25..b86a6047d 100644
--- a/lgsm/functions/command_monitor.sh
+++ b/lgsm/functions/command_monitor.sh
@@ -37,12 +37,12 @@ fn_monitor_msg_checking(){
sleep 1
}
-fn_monitor_email_notification(){
+fn_monitor_email_alert(){
# Email will be sent if enabled
- if [ "${emailnotification}" = "on" ]; then
- commssubject="LGSM - Restarted - ${servername}"
- commsbody="${servicename} process not running"
- comms.sh
+ if [ "${emailalert}" = "on" ]; then
+ alertsubject="LGSM - Restarted - ${servername}"
+ alertbody="${servicename} process not running"
+ alert.sh
fi
}
@@ -57,7 +57,7 @@ fn_monitor_teamspeak3(){
fn_print_fail_eol_nl
fn_scriptlog "Checking session: ${ts3error}: FAIL"
failurereason="${ts3error}"
- fn_monitor_email_notification
+ fn_monitor_email_alert
fi
fn_scriptlog "Monitor is starting ${servername}"
sleep 1
@@ -83,7 +83,7 @@ fn_monitor_tmux(){
fn_print_fail "Checking session: "
fn_print_fail_eol_nl
fn_scriptlog "Checking session: FAIL"
- fn_monitor_email_notification
+ fn_monitor_email_alert
fn_scriptlog "Monitor is starting ${servername}"
sleep 1
command_start.sh
diff --git a/lgsm/functions/command_test_alert.sh b/lgsm/functions/command_test_alert.sh
new file mode 100644
index 000000000..81f8be423
--- /dev/null
+++ b/lgsm/functions/command_test_alert.sh
@@ -0,0 +1,22 @@
+#!/bin/bash
+# LGSM command_email_test.sh function
+# Author: Daniel Gibbs
+# Website: https://gameservermanagers.com
+lgsm_version="140516"
+
+# Description: Sends a test email alert.
+
+local modulename="Alert"
+function_selfname="$(basename $(readlink -f "${BASH_SOURCE[0]}"))"
+
+check.sh
+info_config.sh
+if [ "${emailalert}" = "on" ]||[ "${pushbulletalert}" = "on" ]; then
+ fn_scriptlog "Sending alert Check"
+ alertsubject="LGSM - alert Check - ${servername}"
+ alertbody="LGSM testing alert, how you read?"
+ alert.sh
+else
+ fn_print_fail_nl "alerts not enabled"
+ fn_scriptlog "alerts not enabled"
+fi
\ No newline at end of file
diff --git a/lgsm/functions/comms.sh b/lgsm/functions/comms.sh
deleted file mode 100644
index 1d5a9a091..000000000
--- a/lgsm/functions/comms.sh
+++ /dev/null
@@ -1,15 +0,0 @@
-#!/bin/bash
-# LGSM comms.sh function
-# Author: Daniel Gibbs
-# Website: https://gameservermanagers.com
-lgsm_version="140516"
-
-# Description: Overall function for managing notifications.
-
-if [ "${emailnotification}" == "on" ]||[ -n "${email}" ]; then
- comms_email.sh
-fi
-
-if [ "${pushbulletnotification}" == "on" ]||[ -n "${pushbullettoken}" ]; then
- comms_pushbullet.sh
-fi
\ No newline at end of file
diff --git a/lgsm/functions/comms_pushbullet.sh b/lgsm/functions/comms_pushbullet.sh
deleted file mode 100644
index def5717e9..000000000
--- a/lgsm/functions/comms_pushbullet.sh
+++ /dev/null
@@ -1,14 +0,0 @@
-#!/bin/bash
-# LGSM comms_pushbullet.sh function
-# Author: Daniel Gibbs
-# Website: https://gameservermanagers.com
-lgsm_version="140516"
-
-# Description: Notifications using pushbullet.
-
-local modulename="Comms"
-function_selfname="$(basename $(readlink -f "${BASH_SOURCE[0]}"))"
-
-curl -u """${pushbullettoken}"":" -d type="note" -d body="${commsbody}" -d title="${commssubject}" 'https://api.pushbullet.com/v2/pushes' >/dev/null 2>&1
-fn_print_ok_nl "Sent Pushbullet notification"
-fn_scriptlog "Sent Pushbullet notification"
diff --git a/lgsm/functions/core_functions.sh b/lgsm/functions/core_functions.sh
index e46fe897f..c7d4451bc 100644
--- a/lgsm/functions/core_functions.sh
+++ b/lgsm/functions/core_functions.sh
@@ -111,7 +111,7 @@ functionfile="${FUNCNAME}"
fn_fetch_function
}
-command_comms_check.sh(){
+command_test_alert.sh(){
functionfile="${FUNCNAME}"
fn_fetch_function
}
@@ -332,19 +332,19 @@ fn_fetch_function
}
-# Comms
+# Alert
-comms.sh(){
+alert.sh(){
functionfile="${FUNCNAME}"
fn_fetch_function
}
-comms_email.sh(){
+alert_email.sh(){
functionfile="${FUNCNAME}"
fn_fetch_function
}
-comms_pushbullet.sh(){
+alert_pushbullet.sh(){
functionfile="${FUNCNAME}"
fn_fetch_function
}
diff --git a/lgsm/functions/core_getopt.sh b/lgsm/functions/core_getopt.sh
index f4bb7e9a6..c38df7e99 100644
--- a/lgsm/functions/core_getopt.sh
+++ b/lgsm/functions/core_getopt.sh
@@ -25,8 +25,8 @@ case "$getopt" in
command_validate.sh;;
m|monitor)
command_monitor.sh;;
- et|comms-check)
- command_comms_check.sh;;
+ ct|test-alert)
+ command_test_alert.sh;;
dt|details)
command_details.sh;;
b|backup)
@@ -58,7 +58,7 @@ case "$getopt" in
echo -e "\e[34mupdate-functions\t\e[0muf |Removes all functions so latest can be downloaded."
echo -e "\e[34mvalidate\t\e[0mv |Validate server files with SteamCMD."
echo -e "\e[34mmonitor\t\e[0mm |Checks that the server is running."
- echo -e "\e[34mcomms-check\t\e[0met |Sends test notification."
+ echo -e "\e[34mtest-alert\t\e[0mta |Sends test alert."
echo -e "\e[34mdetails\t\e[0mdt |Displays useful infomation about the server."
echo -e "\e[34mbackup\t\e[0mb |Create archive of the server."
echo -e "\e[34mconsole\t\e[0mc |Console allows you to access the live view of a server."
@@ -84,8 +84,8 @@ case "$getopt" in
command_update_functions.sh;;
m|monitor)
command_monitor.sh;;
- et|comms-check)
- command_comms_check.sh;;
+ et|test-alert)
+ command_test_alert.sh;;
dt|details)
command_details.sh;;
b|backup)
@@ -113,7 +113,7 @@ case "$getopt" in
echo -e "\e[34mupdate\t\e[0mu |Checks and applies updates from SteamCMD."
echo -e "\e[34mupdate-functions\t\e[0muf |Removes all functions so latest can be downloaded."
echo -e "\e[34mmonitor\t\e[0mm |Checks that the server is running."
- echo -e "\e[34mcomms-check\t\e[0met |Sends test notification."
+ echo -e "\e[34mtest-alert\t\e[0mta |Sends test alert."
echo -e "\e[34mdetails\t\e[0mdt |Displays useful infomation about the server."
echo -e "\e[34mchange-password\t\e[0mpw |Changes TS3 serveradmin password."
echo -e "\e[34mbackup\t\e[0mb |Create archive of the server."
@@ -136,8 +136,8 @@ case "$getopt" in
command_update_functions.sh;;
m|monitor)
command_monitor.sh;;
- et|comms-check)
- command_comms_check.sh;;
+ et|test-alert)
+ command_test_alert.sh;;
b|backup)
command_backup.sh;;
dev|dev-debug)
@@ -160,7 +160,7 @@ case "$getopt" in
echo -e "\e[34mrestart\t\e[0mr |Restart the server."
echo -e "\e[34mupdate-functions\t\e[0muf |Removes all functions so latest can be downloaded."
echo -e "\e[34mmonitor\t\e[0mm |Checks that the server is running."
- echo -e "\e[34mcomms-check\t\e[0met |Sends test notification."
+ echo -e "\e[34mtest-alert\t\e[0mta |Sends test alert."
echo -e "\e[34mbackup\t\e[0mb |Create archive of the server."
echo -e "\e[34mconsole\t\e[0mc |Console allows you to access the live view of a server."
echo -e "\e[34mdebug\t\e[0md |See the output of the server directly to your terminal."
@@ -188,8 +188,8 @@ case "$getopt" in
command_validate.sh;;
m|monitor)
command_monitor.sh;;
- et|comms-check)
- command_comms_check.sh;;
+ et|test-alert)
+ command_test_alert.sh;;
dt|details)
command_details.sh;;
b|backup)
@@ -223,7 +223,7 @@ case "$getopt" in
echo -e "\e[34mupdate-functions\t\e[0muf |Removes all functions so latest can be downloaded."
echo -e "\e[34mvalidate\t\e[0mv |Validate server files with SteamCMD."
echo -e "\e[34mmonitor\t\e[0mm |Checks that the server is running."
- echo -e "\e[34mcomms-check\t\e[0met |Sends test notification."
+ echo -e "\e[34mtest-alert\t\e[0mta |Sends test alert."
echo -e "\e[34mdetails\t\e[0mdt |Displays useful infomation about the server."
echo -e "\e[34mbackup\t\e[0mb |Create archive of the server."
echo -e "\e[34mconsole\t\e[0mc |Console allows you to access the live view of a server."
@@ -248,8 +248,8 @@ case "$getopt" in
command_update_functions.sh;;
m|monitor)
command_monitor.sh;;
- et|comms-check)
- command_comms_check.sh;;
+ et|test-alert)
+ command_test_alert.sh;;
dt|details)
command_details.sh;;
b|backup)
@@ -280,7 +280,7 @@ case "$getopt" in
echo -e "\e[34mrestart\t\e[0mr |Restart the server."
echo -e "\e[34mupdate-functions\t\e[0muf |Removes all functions so latest can be downloaded."
echo -e "\e[34mmonitor\t\e[0mm |Checks that the server is running."
- echo -e "\e[34mcomms-check\t\e[0met |Sends test notification."
+ echo -e "\e[34mtest-alert\t\e[0mta |Sends test alert."
echo -e "\e[34mdetails\t\e[0mdt |Displays useful infomation about the server."
echo -e "\e[34mbackup\t\e[0mb |Create archive of the server."
echo -e "\e[34mconsole\t\e[0mc |Console allows you to access the live view of a server."
@@ -313,8 +313,8 @@ case "$getopt" in
command_validate.sh;;
m|monitor)
command_monitor.sh;;
- et|comms-check)
- command_comms_check.sh;;
+ et|test-alert)
+ command_test_alert.sh;;
dt|details)
command_details.sh;;
b|backup)
@@ -348,7 +348,7 @@ case "$getopt" in
echo -e "\e[34mupdate-functions\t\e[0muf |Removes all functions so latest can be downloaded."
echo -e "\e[34mvalidate\t\e[0mv |Validate server files with SteamCMD."
echo -e "\e[34mmonitor\t\e[0mm |Checks that the server is running."
- echo -e "\e[34mcomms-check\t\e[0met |Sends test notification."
+ echo -e "\e[34mtest-alert\t\e[0mta |Sends test alert."
echo -e "\e[34mdetails\t\e[0mdt |Displays useful infomation about the server."
echo -e "\e[34mbackup\t\e[0mb |Create archive of the server."
echo -e "\e[34mconsole\t\e[0mc |Console allows you to access the live view of a server."
@@ -374,8 +374,8 @@ case "$getopt" in
command_update_functions.sh;;
m|monitor)
command_monitor.sh;;
- et|comms-check)
- command_comms_check.sh;;
+ et|test-alert)
+ command_test_alert.sh;;
dt|details)
command_details.sh;;
b|backup)
@@ -408,7 +408,7 @@ case "$getopt" in
echo -e "\e[34mrestart\t\e[0mr |Restart the server."
echo -e "\e[34mupdate-functions\t\e[0muf |Removes all functions so latest can be downloaded."
echo -e "\e[34mmonitor\t\e[0mm |Checks that the server is running."
- echo -e "\e[34mcomms-check\t\e[0met |Sends test notification."
+ echo -e "\e[34mtest-alert\t\e[0mta |Sends test alert."
echo -e "\e[34mdetails\t\e[0mdt |Displays useful infomation about the server."
echo -e "\e[34mbackup\t\e[0mb |Create archive of the server."
echo -e "\e[34mconsole\t\e[0mc |Console allows you to access the live view of a server."
diff --git a/tests/tests_jc2server.sh b/tests/tests_jc2server.sh
index d578b22f4..eac77ae7c 100644
--- a/tests/tests_jc2server.sh
+++ b/tests/tests_jc2server.sh
@@ -7,10 +7,10 @@ version="271215"
#### Variables ####
-# Notification Email
+# Alert Email
# (on|off)
-emailnotification="on"
-email="me@danielgibbs.co.uk"
+emailalert="off"
+email=""
# Steam login
steamuser="anonymous"
diff --git a/tests/tests_ts3server.sh b/tests/tests_ts3server.sh
index 382a9f9be..e9604c7d9 100644
--- a/tests/tests_ts3server.sh
+++ b/tests/tests_ts3server.sh
@@ -7,10 +7,10 @@ version="071115"
#### Variables ####
-# Notification Email
+# Alert Email
# (on|off)
-emailnotification="on"
-email="me@danielgibbs.co.uk"
+emailalert="off"
+email=""
# Start Variables
updateonstart="off"
diff --git a/lgsm/functions/comms_email.sh b/lgsm/functions/alert_email.sh
similarity index 89%
rename from lgsm/functions/comms_email.sh
rename to lgsm/functions/alert_email.sh
index 30601eb4f..4d84a65a7 100644
--- a/lgsm/functions/comms_email.sh
+++ b/lgsm/functions/alert_email.sh
@@ -4,17 +4,17 @@
# Website: https://gameservermanagers.com
lgsm_version="140516"
-# Description: Sends email notification if monitor picks up a failure.
+# Description: Sends email alert if monitor picks up a failure.
-local modulename="Email"
+local modulename="Alert"
fn_details_email(){
#
# Failure reason: Testing bb2-server email notification
# Action Taken: Sent test email...hello is this thing on?
- echo -e "${commsbody}" >> "${emaillog}"
+ echo -e "${alertbody}" >> "${emaillog}"
}
@@ -168,7 +168,7 @@ fn_details_gameserver(){
} | sed -r "s/\x1B\[([0-9]{1,2}(;[0-9]{1,2})?)?[m|K]//g"| tee -a "${emaillog}"
}
-fn_comms_email_template_logs(){
+fn_alert_email_template_logs(){
{
echo -e ""
echo -e "${servicename} Logs"
@@ -214,7 +214,7 @@ fn_comms_email_template_logs(){
} | sed -r "s/\x1B\[([0-9]{1,2}(;[0-9]{1,2})?)?[m|K]//g"| tee -a "${emaillog}"
}
-fn_print_dots "Sending notification to ${email}"
+fn_print_dots "Sending alert to ${email}"
info_distro.sh
info_config.sh
info_glibc.sh
@@ -229,13 +229,13 @@ fn_details_os
fn_details_performance
fn_details_disk
fn_details_gameserver
-fn_comms_email_template_logs
-mail -s "${commssubject}" "${email}" < "${emaillog}"
+fn_alert_email_template_logs
+mail -s "${alertsubject}" "${email}" < "${emaillog}"
exitcode=$?
if [ "${exitcode}" == "0" ]; then
- fn_print_ok_nl "Sending notification to ${email}"
- fn_scriptlog "Success! Sending notification to ${email}"
+ fn_print_ok_nl "Sending alert to ${email}"
+ fn_scriptlog "Success! Sending alert to ${email}"
else
- fn_print_fail_nl "Sending notification to ${email}"
- fn_scriptlog "Failure! Sending notification to ${email}"
+ fn_print_fail_nl "Sending alert to ${email}"
+ fn_scriptlog "Failure! Sending alert to ${email}"
fi
\ No newline at end of file
@@ -4,17 +4,17 @@
fn_details_email(){
#
- # Failure reason: Testing bb2-server email notification
+ # Failure reason: Testing bb2-server email alert
# Action Taken: Sent test email...hello is this thing on?
diff --git a/lgsm/functions/command_details.sh b/lgsm/functions/command_details.sh
index 6ae55f7e1..9fe4ac6bf 100644
--- a/lgsm/functions/command_details.sh
+++ b/lgsm/functions/command_details.sh
@@ -169,7 +169,7 @@ fn_details_script(){
# Service name: ql-server
# qlserver version: 150316
# User: lgsm
# Email notification: off
# Update on start: off
# Location: /home/lgsm/qlserver
# Config file: /home/lgsm/qlserver/serverfiles/baseq3/ql-server.cfg
@@ -205,8 +205,8 @@ fn_details_script(){
fi
fi
- # Email notification
- echo -e "\e[34mEmail notification:\t\e[0m${emailnotification}"
+ # Email alert
+ echo -e "\e[34mEmail alert:\t\e[0m${emailalert}"
# Update on start
echo -e "\e[34mUpdate on start:\t\e[0m${updateonstart}"
@@ -169,7 +169,7 @@ fn_details_script(){
# qlserver version: 150316
# User: lgsm
- # Email notification: off
+ # Email alert: off
# Update on start: off
# Location: /home/lgsm/qlserver
diff --git a/lgsm/functions/monitor_gsquery.sh b/lgsm/functions/monitor_gsquery.sh
index aae83f782..20c7dc3ce 100644
--- a/lgsm/functions/monitor_gsquery.sh
+++ b/lgsm/functions/monitor_gsquery.sh
@@ -68,12 +68,12 @@ if [ "${gsquery}" == "yes" ]; then
fn_scriptlog "Querying port: ${ip}:${port} : ${queryattempt} : FAIL"
sleep 1
- # Send notification if enabled
- if [ "${emailnotification}" == "on" ]; then
+ # Send alert if enabled
+ if [ "${emailalert}" == "on" ]; then
subject="${servicename} Monitor - Starting ${servername}"
failurereason="Failed to query ${servicename}: ${gsquerycmd}"
actiontaken="restarted ${servicename}"
- comms.sh
+ alert.sh
fi
fn_restart
break